#
# spec file for package python-stestr
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-stestr
Version:        2.2.0
Release:        3.11
Summary:        A test runner runner similar to testrepository
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/mtreinish/stestr
Source:         https://files.pythonhosted.org/packages/source/s/stestr/stestr-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML >= 3.10.0}
BuildRequires:  %{python_module cliff >= 2.8.0}
BuildRequires:  %{python_module coverage >= 4.0}
BuildRequires:  %{python_module ddt >= 1.0.1}
BuildRequires:  %{python_module fixtures >= 3.0.0}
BuildRequires:  %{python_module future}
BuildRequires:  %{python_module pbr >= 2.0.0}
BuildRequires:  %{python_module python-subunit >= 1.3.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.10.0}
BuildRequires:  %{python_module testtools >= 2.2.0}
BuildRequires:  %{python_module voluptuous >= 0.8.9}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML >= 3.10.0
Requires:       python-cliff >= 2.8.0
Requires:       python-fixtures >= 3.0.0
Requires:       python-future
Requires:       python-pbr >= 2.0.0
Requires:       python-python-subunit >= 1.3.0
Requires:       python-six >= 1.10.0
Requires:       python-testtools >= 2.2.0
Requires:       python-voluptuous >= 0.8.9
%ifpython3
Requires:       python3-dbm
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if !0%{?_no_weakdeps}
Suggests:       python-subunit2sql >= 1.8.0
%endif
BuildArch:      noarch
%python_subpackages

%description
stestr is a fork of the `testrepository`_ that concentrates on being a
dedicated test runner for python projects. The generic abstraction
layers which enabled testr to work with any subunit emitting runner are gone.
stestr hard codes python-subunit-isms into how it works. The code base is also
designed to try and be explicit, and to provide a python api that is documented
and has examples.

%prep
%setup -q -n stestr-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/stestr
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative stestr

%postun
%python_uninstall_alternative stestr

%files %{python_files}
%license LICENSE
%doc ChangeLog README.rst
%python_alternative %{_bindir}/stestr
%{python_sitelib}/*

%changelog
* Wed Jan  9 2019 jbrownell@suse.com
- Fallback in case "Suggests:" keyword is not supported
* Fri Dec  7 2018 tbechtold@suse.com
- update to 2.2.0:
  * Change title of project in readme
  * Add a better description to README Overview section
  * Fix discovery import error formatting on py3
  * Cleanup unused parameters in \_run\_tests
  * Enable doc8
  * Add all stream to repo even if some tests fail
  * Extract loading case code to \_load\_case() function
  * Make test running serially when just loading
  * Fix time measurement for load command too
  * Use reported times instead of wall time in subunit-trace
  * Add support for test class and method by path on no-discover
* Tue Nov  6 2018 toddrme2178@gmail.com
- Update to version 2.1.1
  * Add support for python 3.7
  * Fix handling of unexpected success results
  * Allow stestr to be called as a module (#185)
  * Add error handling for invalid input regexes
  * Cleanup the manpage section on dealing with failed tests
  * Cleanup argument help text on load command
  * Fix description for the stestr run command
* Fri Aug 24 2018 comurphy@suse.com
- Add python3-dbm dependency
  * Required for python3: https://github.com/mtreinish/stestr/blob/2.1.1/stestr/subunit_trace.py#L34-L39
* Tue Aug  7 2018 dmueller@suse.com
- fixtypo in last change
* Mon Aug  6 2018 tchvatal@suse.com
- Update the Requires/BuildRequires to reflect requirements.txt
* Mon Aug  6 2018 dmueller@suse.com
- update to 2.1.0:
  * Uncap pbr
  * Revert "Cap pip version in windows ci"
  * Revert "Uncap pbr"
  * Uncap pbr
  * Clarify docs on group\_regex
  * Remove Python 2.6 code
  * Switch python doc reference from 2 to 3
  * Cleanup manual section on configuration
  * Fix abbreviate option in run subcommand
  * Ignore errors on cleanup in test\_return\_codes
  * Cap pip version in windows ci
  * Add docs and helper script for building man page
  * Add documentation for --suppress-attachments option
  * Add option to suppress attachment printing on successful tests
  * Add unit tests for return code from functions
  * Remove windows skips for old subunit versions
  * Cap PBR<4.0.0
  * Fixed manual page description
  * Fix manpage generation
  * Add issue description in template
  * Add an issue template to project
  * Add usage to manual docs page
  * Fix the manual docs link in README
  * Add alt texts for badges in README
  * Use flat-square design badges on README
  * Fix typos about whitelist/blacklist option in manual
  * Fix a small mistake in manual about test selection
  * Update the package summary in setup.cfg metadata
  * Add functional tests for user config file
  * Fix no attribute 'repo\_type' error when running w/ --slowest option
  * Add support for a user config file
  * Fix warning message about missing worker tags in subunit-trace
  * Add badge for Appveyor status
  * Remove unnecessary shebang and execution bit from subunit\_trace
  * Fix typos in docs
  * Fix pep8 violations
  * Add --slowest option to test runs
  * Handle zero and negative times in stestr slowest
  * list: Deal with [] instead of 'None' for filters
  * Fix docs nits
  * Update doc for using cliff for CLI layer
  * Use cliff for CLI layer
  * Implement quiet option for run and load commands
  * Deprecate the partial flag
  * Allow both group\_regex and group-regex as an optional argument
  * Remove pyc files before running stestr in tox
  * Update travis job config
* Mon Feb 26 2018 tbechtold@suse.com
  * Pass output to output.make\_result() in stestr load
  * Remove 32bit windows testing CI config
  * Add functional test for analyze-isolation flag
  * Fetch the data from last run earlier
  * Fix the stestr run --analyze-isolation flag
  * Remove contributor docs for using reno
  * Fix stestr load from stdin
  * Add test\_return\_codes check for valid subunit output
  * Respect all selection mechanisms for discovery check
  * Fix .testr.conf parsing: test path follows discover
  * Fix if logic on output types in stestr load
  * Add a --abbreviate flag to stestr run and load
  * Add missing run command to stestr manual
  * Print just error message when no stestr repo
  * Fix whitelist arg usage in stestr run
  * Drop reno
  * Add missing home-page
  * Fix: pass the top\_dir parameter to the 'list' command
  * Fix: pass the test\_path parameter to the 'list' command
  * Update MANUAL.rst
  * Update the trove classifiers
  * Use context managers for file open()
  * Ensure we always close files in file repository
  * Create a Code of Conduct for the project
  * Fix coveralls collection
* Thu Sep 14 2017 tbechtold@suse.com
- initial packaging (version 1.0.0)
